@@ -45,7 +45,7 @@
 			this.m_tbUrl = new System.Windows.Forms.TextBox();
 			this.m_cbExpires = new System.Windows.Forms.CheckBox();
 			this.m_dtExpireDateTime = new System.Windows.Forms.DateTimePicker();
-			this.m_ctxDefaultTimes = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxDefaultTimes = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_menuExpireNow = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_menuExpireSep0 = new System.Windows.Forms.ToolStripSeparator();
 			this.m_menuExpire1Week = new System.Windows.Forms.ToolStripMenuItem();
@@ -82,7 +82,7 @@
 			this.m_btnStrEdit = new System.Windows.Forms.Button();
 			this.m_btnStrDelete = new System.Windows.Forms.Button();
 			this.m_lvStrings = new KeePass.UI.CustomListViewEx();
-			this.m_ctxListOperations = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxListOperations = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_menuListCtxCopyFieldValue = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_tabProperties = new System.Windows.Forms.TabPage();
 			this.m_cmbOverrideUrl = new KeePass.UI.ImageComboBoxEx();
@@ -96,6 +96,8 @@
 			this.m_cbCustomBackgroundColor = new System.Windows.Forms.CheckBox();
 			this.m_btnPickBgColor = new System.Windows.Forms.Button();
 			this.m_tabAutoType = new System.Windows.Forms.TabPage();
+			this.m_btnAutoTypeDown = new System.Windows.Forms.Button();
+			this.m_btnAutoTypeUp = new System.Windows.Forms.Button();
 			this.m_linkAutoTypeObfuscation = new System.Windows.Forms.LinkLabel();
 			this.m_cbAutoTypeObfuscation = new System.Windows.Forms.CheckBox();
 			this.m_btnAutoTypeEditDefault = new System.Windows.Forms.Button();
@@ -115,15 +117,15 @@
 			this.m_lvHistory = new KeePass.UI.CustomListViewEx();
 			this.m_btnTools = new System.Windows.Forms.Button();
 			this.m_bannerImage = new System.Windows.Forms.PictureBox();
-			this.m_ctxStrMoveToStandard = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxStrMoveToStandard = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_menuListCtxMoveStandardTitle = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_menuListCtxMoveStandardUser = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_menuListCtxMoveStandardPassword = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_menuListCtxMoveStandardURL = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_menuListCtxMoveStandardNotes = new System.Windows.Forms.ToolStripMenuItem();
-			this.m_ctxPwGen = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxPwGen = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_ctxPwGenOpen = new System.Windows.Forms.ToolStripMenuItem();
-			this.m_ctxTools = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxTools = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_ctxToolsHelp = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxToolsSep0 = new System.Windows.Forms.ToolStripSeparator();
 			this.m_ctxToolsUrlHelp = new System.Windows.Forms.ToolStripMenuItem();
@@ -136,7 +138,7 @@
 			this.m_ctxToolsFieldRefsInPassword = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxToolsFieldRefsInUrl = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxToolsFieldRefsInNotes = new System.Windows.Forms.ToolStripMenuItem();
-			this.m_ctxBinAttach = new System.Windows.Forms.ContextMenuStrip(this.components);
+			this.m_ctxBinAttach = new KeePass.UI.CustomContextMenuStripEx(this.components);
 			this.m_ctxBinImportFile = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxBinSep0 = new System.Windows.Forms.ToolStripSeparator();
 			this.m_ctxBinNew = new System.Windows.Forms.ToolStripMenuItem();
@@ -420,12 +422,11 @@
 			// m_cbHidePassword
 			// 
 			this.m_cbHidePassword.Appearance = System.Windows.Forms.Appearance.Button;
-			this.m_cbHidePassword.Font = new System.Drawing.Font("Tahoma", 8.25F);
-			this.m_cbHidePassword.Image = global::KeePass.Properties.Resources.B17x05_3BlackDots;
 			this.m_cbHidePassword.Location = new System.Drawing.Point(423, 63);
 			this.m_cbHidePassword.Name = "m_cbHidePassword";
 			this.m_cbHidePassword.Size = new System.Drawing.Size(32, 23);
 			this.m_cbHidePassword.TabIndex = 8;
+			this.m_cbHidePassword.Text = "***";
 			this.m_cbHidePassword.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
 			this.m_cbHidePassword.UseVisualStyleBackColor = true;
 			// 
@@ -804,6 +805,8 @@
 			// 
 			// m_tabAutoType
 			// 
+			this.m_tabAutoType.Controls.Add(this.m_btnAutoTypeDown);
+			this.m_tabAutoType.Controls.Add(this.m_btnAutoTypeUp);
 			this.m_tabAutoType.Controls.Add(this.m_linkAutoTypeObfuscation);
 			this.m_tabAutoType.Controls.Add(this.m_cbAutoTypeObfuscation);
 			this.m_tabAutoType.Controls.Add(this.m_btnAutoTypeEditDefault);
@@ -823,13 +826,33 @@
 			this.m_tabAutoType.Text = "Auto-Type";
 			this.m_tabAutoType.UseVisualStyleBackColor = true;
 			// 
+			// m_btnAutoTypeDown
+			// 
+			this.m_btnAutoTypeDown.Image = global::KeePass.Properties.Resources.B16x16_1DownArrow;
+			this.m_btnAutoTypeDown.Location = new System.Drawing.Point(382, 282);
+			this.m_btnAutoTypeDown.Name = "m_btnAutoTypeDown";
+			this.m_btnAutoTypeDown.Size = new System.Drawing.Size(75, 23);
+			this.m_btnAutoTypeDown.TabIndex = 11;
+			this.m_btnAutoTypeDown.UseVisualStyleBackColor = true;
+			this.m_btnAutoTypeDown.Click += new System.EventHandler(this.OnBtnAutoTypeDown);
+			// 
+			// m_btnAutoTypeUp
+			// 
+			this.m_btnAutoTypeUp.Image = global::KeePass.Properties.Resources.B16x16_1UpArrow;
+			this.m_btnAutoTypeUp.Location = new System.Drawing.Point(382, 253);
+			this.m_btnAutoTypeUp.Name = "m_btnAutoTypeUp";
+			this.m_btnAutoTypeUp.Size = new System.Drawing.Size(75, 23);
+			this.m_btnAutoTypeUp.TabIndex = 10;
+			this.m_btnAutoTypeUp.UseVisualStyleBackColor = true;
+			this.m_btnAutoTypeUp.Click += new System.EventHandler(this.OnBtnAutoTypeUp);
+			// 
 			// m_linkAutoTypeObfuscation
 			// 
 			this.m_linkAutoTypeObfuscation.AutoSize = true;
 			this.m_linkAutoTypeObfuscation.Location = new System.Drawing.Point(208, 314);
 			this.m_linkAutoTypeObfuscation.Name = "m_linkAutoTypeObfuscation";
 			this.m_linkAutoTypeObfuscation.Size = new System.Drawing.Size(68, 13);
-			this.m_linkAutoTypeObfuscation.TabIndex = 11;
+			this.m_linkAutoTypeObfuscation.TabIndex = 13;
 			this.m_linkAutoTypeObfuscation.TabStop = true;
 			this.m_linkAutoTypeObfuscation.Text = "What is this?";
 			this.m_linkAutoTypeObfuscation.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.OnAutoTypeObfuscationLink);
@@ -840,7 +863,7 @@
 			this.m_cbAutoTypeObfuscation.Location = new System.Drawing.Point(9, 313);
 			this.m_cbAutoTypeObfuscation.Name = "m_cbAutoTypeObfuscation";
 			this.m_cbAutoTypeObfuscation.Size = new System.Drawing.Size(193, 17);
-			this.m_cbAutoTypeObfuscation.TabIndex = 10;
+			this.m_cbAutoTypeObfuscation.TabIndex = 12;
 			this.m_cbAutoTypeObfuscation.Text = "Two-channel auto-type obfuscation";
 			this.m_cbAutoTypeObfuscation.UseVisualStyleBackColor = true;
 			this.m_cbAutoTypeObfuscation.CheckedChanged += new System.EventHandler(this.OnAutoTypeObfuscationCheckedChanged);
@@ -1322,7 +1345,7 @@
 		private System.Windows.Forms.Button m_btnHistoryView;
 		private KeePass.UI.CustomListViewEx m_lvHistory;
 		private System.Windows.Forms.Button m_btnHistoryDelete;
-		private System.Windows.Forms.ContextMenuStrip m_ctxDefaultTimes;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxDefaultTimes;
 		private System.Windows.Forms.ToolStripMenuItem m_menuExpireNow;
 		private System.Windows.Forms.ToolStripSeparator m_menuExpireSep0;
 		private System.Windows.Forms.ToolStripMenuItem m_menuExpire1Week;
@@ -1333,7 +1356,7 @@
 		private System.Windows.Forms.ToolStripMenuItem m_menuExpire6Months;
 		private System.Windows.Forms.ToolStripSeparator m_menuExpireSep2;
 		private System.Windows.Forms.ToolStripMenuItem m_menuExpire1Year;
-		private System.Windows.Forms.ContextMenuStrip m_ctxListOperations;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxListOperations;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxCopyFieldValue;
 		private System.Windows.Forms.TextBox m_tbDefaultAutoTypeSeq;
 		private System.Windows.Forms.CheckBox m_cbAutoTypeEnabled;
@@ -1342,13 +1365,13 @@
 		private System.Windows.Forms.RadioButton m_rbAutoTypeSeqInherit;
 		private System.Windows.Forms.Button m_btnAutoTypeEditDefault;
 		private System.Windows.Forms.Button m_btnStrMove;
-		private System.Windows.Forms.ContextMenuStrip m_ctxStrMoveToStandard;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxStrMoveToStandard;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardTitle;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardUser;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardPassword;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardURL;
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardNotes;
-		private System.Windows.Forms.ContextMenuStrip m_ctxPwGen;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxPwGen;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxPwGenOpen;
 		private System.Windows.Forms.TabPage m_tabProperties;
 		private System.Windows.Forms.Button m_btnPickBgColor;
@@ -1359,7 +1382,7 @@
 		private KeePass.UI.SplitButtonEx m_btnBinOpen;
 		private System.Windows.Forms.TextBox m_tbUuid;
 		private System.Windows.Forms.Label m_lblUuid;
-		private System.Windows.Forms.ContextMenuStrip m_ctxTools;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxTools;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxToolsHelp;
 		private System.Windows.Forms.ToolStripSeparator m_ctxToolsSep0;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxToolsUrlHelp;
@@ -1376,11 +1399,13 @@
 		private System.Windows.Forms.CheckBox m_cbCustomForegroundColor;
 		private System.Windows.Forms.TextBox m_tbTags;
 		private System.Windows.Forms.Label m_lblTags;
-		private System.Windows.Forms.ContextMenuStrip m_ctxBinAttach;
+		private KeePass.UI.CustomContextMenuStripEx m_ctxBinAttach;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxBinImportFile;
 		private System.Windows.Forms.ToolStripSeparator m_ctxBinSep0;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxBinNew;
 		private KeePass.UI.ImageComboBoxEx m_cmbOverrideUrl;
+		private System.Windows.Forms.Button m_btnAutoTypeDown;
+		private System.Windows.Forms.Button m_btnAutoTypeUp;
 
 	}
 }
\ No newline at end of file
