@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@ namespace KeePass.Native
 {
 	internal static partial class NativeMethods
 	{
+		internal const int WM_SETFOCUS = 0x0007;
+		internal const int WM_KILLFOCUS = 0x0008;
 		internal const int WM_KEYDOWN = 0x0100;
 		internal const int WM_KEYUP = 0x0101;
 		internal const int WM_DRAWCLIPBOARD = 0x0308;
@@ -42,9 +44,16 @@ namespace KeePass.Native
 		internal const int WM_RBUTTONDOWN = 0x0204;
 		internal const int WM_MBUTTONDOWN = 0x0207;
 		// internal const int WM_MOUSEWHEEL = 0x020A;
+		// internal const int WM_ERASEBKGND = 0x0014;
 
 		internal const int WM_NOTIFY = 0x004E;
 
+		// See Control.ReflectMessageInternal;
+		// http://msdn.microsoft.com/en-us/library/eeah46xd.aspx
+		internal const int WM_REFLECT = 0x2000;
+
+		internal const int WM_NOTIFY_REFLECT = (WM_NOTIFY + WM_REFLECT);
+
 		internal const int WM_GETTEXTLENGTH = 0x000E;
 		internal const int WM_GETICON = 0x007F;
 
@@ -74,15 +83,16 @@ namespace KeePass.Native
 		internal const int VK_RWIN = 0x5C;
 		internal const int VK_SNAPSHOT = 0x2C;
 
-		internal const int VK_F5 = 0x74;
-		internal const int VK_F6 = 0x75;
-		internal const int VK_F7 = 0x76;
-		internal const int VK_F8 = 0x77;
+		// internal const int VK_F5 = 0x74;
+		// internal const int VK_F6 = 0x75;
+		// internal const int VK_F7 = 0x76;
+		// internal const int VK_F8 = 0x77;
 
 		internal const uint KEYEVENTF_EXTENDEDKEY = 1;
 		internal const uint KEYEVENTF_KEYUP = 2;
 		internal const uint KEYEVENTF_UNICODE = 4;
 
+		// internal const uint GW_CHILD = 5;
 		internal const uint GW_HWNDNEXT = 2;
 
 		internal const int GWL_STYLE = -16;
@@ -90,6 +100,8 @@ namespace KeePass.Native
 
 		internal const int WS_VISIBLE = 0x10000000;
 
+		// internal const int WS_EX_COMPOSITED = 0x02000000;
+
 		internal const int SW_SHOW = 5;
 
 		internal const int GCLP_HICON = -14;
@@ -126,11 +138,14 @@ namespace KeePass.Native
 		internal const uint FSCTL_UNLOCK_VOLUME = 589852;
 
 		internal const int LVM_FIRST = 0x1000;
-		internal const int LVM_ENSUREVISIBLE = LVM_FIRST + 19;
+		// internal const int LVM_ENSUREVISIBLE = LVM_FIRST + 19;
 		internal const int LVM_SCROLL = LVM_FIRST + 20;
 		// internal const int LVM_SETGROUPINFO = LVM_FIRST + 147; // >= Vista
 		// internal const int LVM_GETGROUPINFOBYINDEX = LVM_FIRST + 153; // >= Vista
 
+		internal const int TV_FIRST = 0x1100;
+		internal const int TVM_SETEXTENDEDSTYLE = TV_FIRST + 44;
+
 		internal const int WM_MOUSEACTIVATE = 0x21;
 		internal const int MA_ACTIVATE = 1;
 		internal const int MA_ACTIVATEANDEAT = 2;
@@ -185,6 +200,13 @@ namespace KeePass.Native
 		internal const uint SND_FILENAME = 0x00020000;
 		internal const uint SND_NODEFAULT = 0x0002;
 
+		internal const int LOGPIXELSX = 88;
+		internal const int LOGPIXELSY = 90;
+
+		// internal const uint PROCESS_QUERY_INFORMATION = 0x0400;
+
+		internal const uint ACTCTX_FLAG_ASSEMBLY_DIRECTORY_VALID = 0x04;
+
 		// internal const uint DI_NORMAL = 0x0003;
 
 		// internal const int LVN_FIRST = -100;
@@ -349,5 +371,19 @@ namespace KeePass.Native
 			Continue = 11, // IDCONTINUE
 			TimeOut = 32000 // IDTIMEOUT
 		} */
+
+		[Flags]
+		internal enum ToolHelpFlags : uint
+		{
+			SnapHeapList = 0x00000001,
+			SnapProcess = 0x00000002,
+			SnapThread = 0x00000004,
+			SnapModule = 0x00000008,
+			SnapModule32 = 0x00000010,
+
+			SnapAll = (SnapHeapList | SnapProcess | SnapThread | SnapModule),
+
+			Inherit = 0x80000000U
+		}
 	}
 }
