@@ -21,30 +21,20 @@ using System;
 using System.Collections.Generic;
 using System.Text;
 using System.Windows.Forms;
-using System.IO;
 using System.Runtime.InteropServices;
-using System.Reflection;
 using System.Diagnostics;
 
+using KeePass.Forms;
 using KeePass.UI;
-using KeePass.Util;
 
-using KeePassLib;
 using KeePassLib.Utility;
 
-using KeeNativeLib = KeePassLib.Native;
+using NativeLib = KeePassLib.Native.NativeLib;
 
 namespace KeePass.Native
 {
 	internal static partial class NativeMethods
 	{
-		[StructLayout(LayoutKind.Sequential)]
-		private struct XClassHint
-		{
-			public IntPtr res_name;
-			public IntPtr res_class;
-		}
-
 		/* private const string PathLibDo = "/usr/lib/gnome-do/libdo";
 		private const UnmanagedType NtvStringType = UnmanagedType.LPStr;
 
@@ -81,9 +71,6 @@ namespace KeePass.Native
 
 		internal delegate void BindKeyHandler(string strKey, IntPtr lpUserData); */
 
-		[DllImport("libX11")]
-		private static extern int XSetClassHint(IntPtr display, IntPtr window, IntPtr class_hints);
-
 		private static bool LoseFocusUnix(Form fCurrent)
 		{
 			if(fCurrent == null) { Debug.Assert(false); return true; }
@@ -94,6 +81,10 @@ namespace KeePass.Native
 				long lCurrent;
 				long.TryParse(strCurrent.Trim(), out lCurrent);
 
+				MainForm mf = Program.MainForm;
+				Debug.Assert(mf == fCurrent);
+				if(mf != null) mf.UIBlockWindowStateAuto(true);
+
 				UIUtil.SetWindowState(fCurrent, FormWindowState.Minimized);
 
 				int nStart = Environment.TickCount;
@@ -108,6 +99,8 @@ namespace KeePass.Native
 					if(lActive != lCurrent) break;
 				}
 
+				if(mf != null) mf.UIBlockWindowStateAuto(false);
+
 				return true;
 			}
 			catch(Exception) { Debug.Assert(false); }
@@ -135,8 +128,7 @@ namespace KeePass.Native
 			try
 			{
 				Application.DoEvents(); // E.g. for clipboard updates
-				string strOutput = KeeNativeLib.NativeLib.RunConsoleApp(
-					"xdotool", strParams);
+				string strOutput = NativeLib.RunConsoleApp("xdotool", strParams);
 				Application.DoEvents(); // E.g. for clipboard updates
 				return (strOutput ?? string.Empty);
 			}
@@ -145,75 +137,6 @@ namespace KeePass.Native
 			return string.Empty;
 		}
 
-		private static Type m_tXplatUIX11 = null;
-		private static Type GetXplatUIX11Type(bool bThrowOnError)
-		{
-			if(m_tXplatUIX11 == null)
-			{
-				CheckState cs = CheckState.Indeterminate; // In System.Windows.Forms
-				string strTypeCS = cs.GetType().AssemblyQualifiedName;
-				string strTypeX11 = strTypeCS.Replace("CheckState", "XplatUIX11");
-				m_tXplatUIX11 = Type.GetType(strTypeX11, bThrowOnError, true);
-			}
-
-			return m_tXplatUIX11;
-		}
-
-		private static Type m_tHwnd = null;
-		private static Type GetHwndType(bool bThrowOnError)
-		{
-			if(m_tHwnd == null)
-			{
-				CheckState cs = CheckState.Indeterminate; // In System.Windows.Forms
-				string strTypeCS = cs.GetType().AssemblyQualifiedName;
-				string strTypeHwnd = strTypeCS.Replace("CheckState", "Hwnd");
-				m_tHwnd = Type.GetType(strTypeHwnd, bThrowOnError, true);
-			}
-
-			return m_tHwnd;
-		}
-
-		internal static void SetWmClass(Form f, string strName, string strClass)
-		{
-			if(f == null) { Debug.Assert(false); return; }
-
-			// The following crashes under Mac OS X (SIGSEGV in native code,
-			// not just an exception), thus skip it when we're on Mac OS X
-			// https://sourceforge.net/projects/keepass/forums/forum/329221/topic/5860588
-			if(KeeNativeLib.NativeLib.GetPlatformID() == PlatformID.MacOSX)
-				return;
-
-			try
-			{
-				Type tXplatUIX11 = GetXplatUIX11Type(true);
-				FieldInfo fiDisplayHandle = tXplatUIX11.GetField("DisplayHandle",
-					BindingFlags.NonPublic | BindingFlags.Static);
-				IntPtr hDisplay = (IntPtr)fiDisplayHandle.GetValue(null);
-
-				Type tHwnd = GetHwndType(true);
-				MethodInfo miObjectFromHandle = tHwnd.GetMethod("ObjectFromHandle",
-					BindingFlags.Public | BindingFlags.Static);
-				object oHwnd = miObjectFromHandle.Invoke(null, new object[] { f.Handle });
-
-				FieldInfo fiWholeWindow = tHwnd.GetField("whole_window",
-					BindingFlags.NonPublic | BindingFlags.Instance);
-				IntPtr hWindow = (IntPtr)fiWholeWindow.GetValue(oHwnd);
-
-				XClassHint xch = new XClassHint();
-				xch.res_name = Marshal.StringToCoTaskMemAnsi(strName ?? string.Empty);
-				xch.res_class = Marshal.StringToCoTaskMemAnsi(strClass ?? string.Empty);
-				IntPtr pXch = Marshal.AllocCoTaskMem(Marshal.SizeOf(xch));
-				Marshal.StructureToPtr(xch, pXch, false);
-
-				XSetClassHint(hDisplay, hWindow, pXch);
-
-				Marshal.FreeCoTaskMem(pXch);
-				Marshal.FreeCoTaskMem(xch.res_name);
-				Marshal.FreeCoTaskMem(xch.res_class);
-			}
-			catch(Exception) { Debug.Assert(false); }
-		}
-
 		/* private static Dictionary<string, Assembly> m_dAsms = null;
 		internal static Assembly LoadAssembly(string strAsmName, string strFileName)
 		{
